Package: sdm
Type: Package
Title: Species Distribution Modelling
Version: 1.2-59
Date: 2025-07-13
Authors@R: c(person(given = "Babak",
                      family = "Naimi",
                      role = c("aut", "cre"),
                      email = "naimi.b@gmail.com",
                      comment = c(ORCID = "0000-0001-5431-2729")),
               person(given = c("Miguel", "B."),
                      family = "Araujo",
                      role = "aut"))
Depends: methods, R (>= 3.5.0), terra
Imports: sp, raster
Suggests: R.rsp, shinyBS, shiny, dismo
Description: An extensible framework for developing species distribution
    models using individual and community-based approaches, generate ensembles of
    models, evaluate the models, and predict species potential distributions in
    space and time. For more information, please check the following paper:
    Naimi, B., Araujo, M.B. (2016) <doi:10.1111/ecog.01881>.
License: GPL (>= 3)
URL: https://www.biogeoinformatics.org
VignetteBuilder: R.rsp
NeedsCompilation: no
Packaged: 2025-07-13 00:38:49 UTC; naimi001
Author: Babak Naimi [aut, cre] (ORCID: <https://orcid.org/0000-0001-5431-2729>),
  Miguel B. Araujo [aut]
Maintainer: Babak Naimi <naimi.b@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-13 02:30:02 UTC
Built: R 4.3.3; ; 2025-07-14 22:23:58 UTC; unix
